#
# spec file for package python-pylru
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pylru
Version:        1.2.1
Release:        1.8
Summary:        A least recently used (LRU) cache implementation
License:        GPL-2.0-only
Group:          Development/Languages/Python
URL:            https://github.com/jlhutch/pylru
Source:         https://files.pythonhosted.org/packages/source/p/pylru/pylru-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Pylru implements a true LRU cache along with several support classes. The cache is efficient and written in pure Python. It works with Python 2.6+ including the 3.x series. Basic operations (lookup, insert, delete) all run in a constant amount of time. Pylru provides a cache class with a simple dict interface. It also provides classes to wrap any object that has a dict interface with a cache. Both write-through and write-back semantics are supported. Pylru also provides classes to wrap functions in a similar way, including a function decorator.

%prep
%setup -q -n pylru-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python test.py

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/*

%changelog
* Wed Oct  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to Version 1.2.1
  * Small optimization to popitem().
  * Improved comments, removed whitespace, etc.
  * Added __getstate__() and __setstate__().
  * Moved from distutils to setuptools in setup.py
  * Moved readme to Restructured Text.
- Update to Version 1.2.0
  * Renamed the markdown formatted README.txt to README.md
  * Updated documentation.
  * Added optional callback to FunctionCacheManager.
  * Merge pull request #28 from marc1n/master
  * Minimize memory consuption of _dlnode
  * Merge pull request #26 from bpsuntrup/master
  * Add optional callback funtionality to lrudecorator.
- Update to version to 1.1.0
  * Added pop, popitem, and setdefault methods to lrucache class.
  * Improved update() method of lrucache.
  * Added len() method to WriteBackCacheManager.
  * Simplified logic of a couple __getitem__ implementations.
  * Cleaned up some of the comments and whitespace.
  * Merge pull request #22 from btimby/master
  * Undo whitespace changes.
  * Added update() method.
  * Merge pull request #20 from pp-qq/patch-1
  * refactor(lrucache): improve lrucache.get()
  * Fixes #13, a bug in lrudecorator.
  * Small change to README.
  * Small change to README.
  * Moved version to 1.0.8
  * Added documentation for FunctionCacheManager.
  * lrudecorator now updates the metadata to look more like the wrapped function.
  * Refactored lrudecorator using FunctionCacheManager.
  * Added clear() and size() to FunctionCacheManager.
  * Added FunctionCacheManager.
* Fri Dec  6 2019 Erico Mendonca <erico.mendonca@suse.com>
- Initial version.
